betty.extension.deriver package - Betty 0.4.0a4 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.deriver package

## Module contents

Expand an ancestry by deriving additional data from existing data.

final class betty.extension.deriver.Deriver

  Bases: `Extension`

  Expand an ancestry by deriving additional data from existing data.

  classmethod comes_before() → set[PluginId]

    The extensions that this one comes before.

    The other extensions may or may not be enabled.

  classmethod plugin_description() → Localizable

    Get the human-readable long plugin description.

  classmethod plugin_id() → PluginId

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

  classmethod plugin_label() → Localizable

    Get the human-readable short plugin label.

  register_event_handlers(registry: EventHandlerRegistry) → None

    Register event handlers with the project.